@@ -1,16 +1,15 @@
 from __future__ import print_function
 import requests
-from asyncio import get_event_loop, AbstractEventLoop
 from json import loads
-
 from . import errors
 
-class Client:
+class Client (self):
     """
     API client for gtchecker.com
     """
-    def __init__(self, token: str = None, *):
+    def __init__(self, token: str = None, *, baseurl: str = "https://gtchecker.com/api/v1/"):
         self.token = token
+        self.baseurl = baseurl
         
 
     async def get_gamertag(self, gamertag: str):
@@ -20,8 +19,8 @@ class Client:
         headers = {'Authorization': self.token}
         if not self.token:
             raise errors.InvalidTokenError("No token was supplied")
-        r = await request.post("https://gtchecker.com/api/v1/xbox?gamertag={}".format(gamertag), headers=headers)
-        data = loads(await r.text())
+        r = requests.post(self.baseurl+"xbox?gamertag={}".format(gamertag), headers=headers)
+        data = r.json()
         return data
         if r.status != 200:
             raise errors.InvalidTokenError("Invalid token was supplied")
@@ -33,8 +32,8 @@ class Client:
         headers = {'Authorization': self.token}
         if not self.token:
             raise errors.InvalidTokenError("No token was supplied")
-        r = await request.post("https://gtchecker.com/api/v1/psn?psn={}".format(psn), headers=headers)
-        data = loads(await r.text())
+        r = requests.post(self.baseurl+"psn?psn={}".format(gamertag), headers=headers)
+        data = r.json()
         return data
         if r.status != 200:
             raise errors.InvalidTokenError("Invalid token was supplied")
